utils::globalVariables(c("AB", "Abstract", "Abstract_no", "Animal_score", "Biomarker_score", "Content", "DP",
                         "Freq", "LA", "Mentioned_n", "PMID", "PT", "Patient_score", "Perplexity", "SNPs", "TI",
                         "Target", "Target_count", "Term", "Topic", "Type", "V3", "Var1", "Var2", "Year", "df_mirtarbase", "document",
                         "first_mentioned", "k", "key", "log2_ratio", "max_score", "miR", "miRNA", "miRNA_count",
                         "miRNA_excel", "miRNA_tarbase", "mirna_count", "n", "n_abstracts_topic",
                         "n_abstracts_word", "n_row", "new_miRNAs", "ngram_stopwords", "no_of_abstract",
                         "no_per_topic", "no_topic", "number_topic", "perc", "perc_abstract", "perc_per_topic",
                         "sort_out", "stopwords_miretrieve", "sums", "term", "term_score", "tf_idf", "threshold",
                         "topic", "topic_score", "total", "value", "word", "miR_extract"))


